"""
A CLI tool to deobfuscate & download manga chapters from multiple official Japanese providers.
"""

__version__ = "0.1.7"
__description__ = "A CLI tool to deobfuscate & download manga chapters from multiple official Japanese providers."
__repository__ = "syvixor/laine"
__url_repository__ = "https://github.com"
__author__ = "syvixor"
__author_email__ = "syvixor@proton.me"
__license__ = "MIT"